# systemd options
%global _has_systemd %(eval rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: NVMe SSD monitoring tool
Name: nvmemon
Version: 2.4.4
Release: 1%{?dist}
Group: System Environment/Daemons
License: GPLv2+
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: %{name}.%{_servicefile_postfix}
Source1: %{name}.sysconfig
Source2: %{name}.sh.in
Source3: %{name}.cron
%if %{_has_systemd}
Source4: %{name}-tmpfiles.conf
%endif
Source5: README.%{name}
Source6: CREDITS.%{name}
Source7: http://www.gnu.org/licenses/gpl.txt
Requires: sendEmail >= 1.50, beep, grep, util-linux, sed, nvme-cli
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
BuildRequires: sed
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
NVMemon is a shell script which runs as a daemon and monitors NVMe SSD
devices. It starts to beep when a device fails. Every event also
triggers the email alert mechanism, which sends mail to one or more
persons with the details of what's going on.

%prep
%{__install} -d %{_builddir}/%{name}-%{version}
%{__install} -m 0644 -p %{SOURCE5} %{_builddir}/%{name}-%{version}/README
%{__install} -m 0644 -p %{SOURCE6} %{_builddir}/%{name}-%{version}/CREDITS
%{__install} -m 0644 -p %{SOURCE7} %{_builddir}/%{name}-%{version}/LICENSE

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_sysconfdir}/cron.daily
%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE0} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE0} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__sed} -e "s@\/var\/run\/@%{_pidbasedir}/@g" %{SOURCE2} > %{buildroot}%{_bindir}/%{name}
%{__chmod} 0755 %{buildroot}%{_bindir}/%{name}
%{__install} -m 0755 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/cron.daily/0%{name}

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%{_bindir}/systemctl daemon-reload > /dev/null 2>&1 || :
if [ $1 -ge 1 ]; then
  %{_bindir}/%{name} try-restart > /dev/null 2>&1 || :
fi
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc %{name}-%{version}/README %{name}-%{version}/CREDITS %{name}-%{version}/LICENSE
%{_bindir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}
%endif
%attr(0755,root,root) %dir %{_pidbasedir}/%{name}
%attr(0755,root,root) %config %{_sysconfdir}/cron.daily/0%{name}

%changelog
* Tue Jun 11 2024 Simon Matter <simon.matter@invoca.ch> 2.4.4-1
- cleanup smart info in status

* Mon Mar 06 2023 Simon Matter <simon.matter@invoca.ch> 2.4.3-4
- add also Wants=network-online.target to systemd unit files

* Fri Mar 03 2023 Simon Matter <simon.matter@invoca.ch> 2.4.3-3
- add network-online requirement to systemd unit files

* Mon Jan 23 2023 Simon Matter <simon.matter@invoca.ch> 2.4.3-1
- upgrade to 2.4.3 (improve mechanism for reexec)

* Fri Jan 20 2023 Simon Matter <simon.matter@invoca.ch> 2.4.2-1
- upgrade to 2.4.2 (improve syslog info)

* Fri Jan 20 2023 Simon Matter <simon.matter@invoca.ch> 2.4.1-1
- upgrade to 2.4.1 (improve reload function)

* Thu Jan 19 2023 Simon Matter <simon.matter@invoca.ch> 2.4.0-1
- upgrade to 2.4.0 (refactoring for new bash style)

* Thu Aug 19 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-3
- improve init script

* Wed Aug 18 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-2
- fix inconsistency between init scripts and systemd

* Wed Aug 18 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-1
- upgrade to 2.2.5

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.2.4-1
- upgrade to 2.2.4

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.2.3-1
- upgrade to 2.2.3

* Sat Aug 14 2021 Simon Matter <simon.matter@invoca.ch> 2.2.2-1
- upgrade to 2.2.2

* Fri Aug 13 2021 Simon Matter <simon.matter@invoca.ch> 2.2.1-1
- upgrade to 2.2.1

* Fri Aug 13 2021 Simon Matter <simon.matter@invoca.ch> 2.2.0-1
- upgrade to 2.2.0

* Fri Dec 04 2020 Simon Matter <simon.matter@invoca.ch> 2.1.7-1
- upgrade to 2.1.7

* Mon Apr 20 2020 Simon Matter <simon.matter@invoca.ch> 2.1.6-1
- upgrade to 2.1.6
- add support for EL8

* Thu Apr 25 2019 Simon Matter <simon.matter@invoca.ch> 2.1.5-1
- upgrade to 2.1.5

* Thu Sep 13 2018 Simon Matter <simon.matter@invoca.ch> 2.1.3-1
- upgrade to 2.1.3

* Tue Sep 11 2018 Simon Matter <simon.matter@invoca.ch> 2.1.2-1
- upgrade to 2.1.2

* Tue Sep 11 2018 Simon Matter <simon.matter@invoca.ch> 2.1.1-1
- upgrade to 2.1.1

* Tue Sep 11 2018 Simon Matter <simon.matter@invoca.ch> 2.1.0-1
- initial build
